import React, { useMemo } from 'react';
import { log } from './common/log';
import { env } from './common/env';
export function Row({ name, item, onEdit, onDelete }) {
    const db = env.db;
    const validation = env.validation;
    const dbTable = useMemo(() => db[name], [name]);
    const fields = useMemo(() => validation.getOwnFields(name), [name]);
    // FIXME quick clicks
    const handleDelete = async () => {
        try {
            const id = item.id;
            log('[Row.handleDelete]', id);
            await dbTable.delete(id);
            onDelete && onDelete(id);
        }
        catch (error) {
            alert(error.message);
        }
    };
    return React.createElement("tr", { key: item.id + '' },
        React.createElement("td", null,
            React.createElement("i", { className: 'icon delete', onClick: handleDelete }),
            React.createElement("i", { className: 'icon edit', onClick: () => onEdit && onEdit() })),
        fields.map(f => React.createElement("td", { key: f },
            React.createElement(Field, { table: name, item: item, f: f }))));
}
function Field({ table, item, f }) {
    const validation = env.validation;
    const ps = useMemo(() => validation.getOwnProperties(table), [table]);
    const type = ps[f].type;
    switch (type) {
        case 'number':
        case 'integer':
        case 'string':
            return React.createElement(React.Fragment, null, item[f]);
        case 'boolean':
            return React.createElement("input", { type: 'checkbox', checked: item[f], disabled: true, className: 'type-' + type });
        case 'object':
        case 'array':
            return React.createElement(React.Fragment, null, JSON.stringify(item[f]));
        case 'null':
            return React.createElement(React.Fragment, null, "null");
    }
}
