"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ObjectUI = void 0;
const react_1 = __importStar(require("react"));
const lodash_1 = require("lodash");
const json_server_orm_1 = require("json-server-orm");
const log_1 = require("./common/log");
function ObjectUI({ name, db }) {
    const dbObject = react_1.useMemo(() => db[name], [name]);
    const [object, setObject] = react_1.useState();
    const [editable, setEditable] = react_1.useState(false);
    react_1.useEffect(() => {
        (async () => {
            try {
                const obj = await dbObject.one();
                log_1.log('[Object]', obj);
                setObject(obj);
                setEditable(false);
            }
            catch (error) {
                alert(error.message);
            }
        })();
    }, [name]);
    const handleUpdate = async (obj) => {
        setObject(obj);
        setEditable(false);
    };
    return react_1.default.createElement("div", { className: 'object' }, editable
        ? react_1.default.createElement(EditableRow, { db: db, name: name, object: object, onCancel: () => setEditable(false), onSubmit: handleUpdate })
        : react_1.default.createElement(Row, { object: object, onEdit: () => setEditable(true) }));
}
exports.ObjectUI = ObjectUI;
function EditableRow({ db, name, object, onSubmit, onCancel }) {
    const dbObject = react_1.useMemo(() => db[name], [name]);
    const [obj, setObj] = react_1.useState(lodash_1.cloneDeep(object));
    const [error, setError] = react_1.useState();
    const handleUpdate = async () => {
        try {
            const o = await dbObject.update(obj, true);
            console.log(o);
            onSubmit && onSubmit(o);
        }
        catch (err) {
            if (err.response)
                err = new json_server_orm_1.ValidationError(err.response.data.message, err.response.data.field);
            if (err instanceof json_server_orm_1.ValidationError && err.field)
                setError(err);
            else
                alert(err.message);
        }
    };
    return react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("textarea", { className: 'type-object', value: typeof obj === 'string' ? obj : JSON.stringify(obj, null, 2), onChange: (ev) => setObj(ev.target.value), onBlur: (ev) => setObj(JSON.parse(ev.target.value)) }),
        error && react_1.default.createElement("div", { className: 'error' },
            "[",
            error.field,
            "]: ",
            error.message),
        react_1.default.createElement("br", null),
        react_1.default.createElement("button", { className: 'icon submit', onClick: handleUpdate }, "Submit"),
        react_1.default.createElement("button", { className: 'icon cancel', onClick: () => onCancel && onCancel() }, "Cancel"));
}
function Row({ object, onEdit }) {
    return react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("pre", { className: 'type-object', onClick: () => onEdit && onEdit() }, JSON.stringify(object, null, 2)),
        react_1.default.createElement("button", { className: 'icon edit', onClick: () => onEdit && onEdit() }, "Edit"));
}
