"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableUI = void 0;
const react_1 = __importStar(require("react"));
const use_force_update_1 = __importDefault(require("use-force-update"));
const log_1 = require("./common/log");
const Row_1 = require("./Row");
const EditableRow_1 = require("./EditableRow");
const env_1 = require("./common/env");
function TableUI({ name, limit, q, db }) {
    const validation = env_1.env.validation;
    const forceUpdate = use_force_update_1.default();
    const fields = react_1.useMemo(() => validation.getOwnFields(name), [name]);
    const dbTable = react_1.useMemo(() => db[name], [name]);
    const [items, setItems] = react_1.useState([]);
    const [addable, setAddable] = react_1.useState(false);
    const [editId, setEditId] = react_1.useState(0);
    const [count, setCount] = react_1.useState(0);
    const [sort, setSort] = react_1.useState(['id', 'desc']);
    react_1.useEffect(() => {
        (async () => {
            try {
                const opts = { sort: sort[0], order: sort[1] };
                if (limit)
                    opts.limit = limit;
                if (q)
                    opts.q = q;
                const its = await dbTable.all(opts);
                log_1.log(`[Table] ${its.length} items loaded, opts`, opts);
                setItems(its);
                setCount(await dbTable.count());
            }
            catch (error) {
                alert(error.message);
            }
        })();
    }, [name, limit, q, sort]);
    const handleDelete = async (id) => {
        items.splice(items.findIndex(o => o.id === id), 1);
        forceUpdate();
        setCount(await dbTable.count());
    };
    const handleUpdate = async (item) => {
        Object.assign(items.find(o => o.id === item.id), item);
        setEditId(0);
    };
    const handleAdd = async (item) => {
        items.unshift(item);
        setAddable(false);
        setCount(await dbTable.count());
    };
    const handleSort = async (field) => {
        setSort([field, sort[1] === 'desc' ? 'asc' : 'desc']);
    };
    return !fields ? null : react_1.default.createElement("table", { className: 'table table-light' },
        react_1.default.createElement("thead", null,
            react_1.default.createElement("tr", null,
                react_1.default.createElement("th", null,
                    !addable &&
                        react_1.default.createElement("i", { className: 'icon add', onClick: () => setAddable(true) }),
                    count),
                fields.map(f => (react_1.default.createElement("th", { key: f, className: f === sort[0] ? sort[1] : '', onClick: () => handleSort(f) }, f))))),
        react_1.default.createElement("tbody", null,
            addable &&
                react_1.default.createElement(EditableRow_1.EditableRow, { table: name, onSubmit: handleAdd, onCancel: () => setAddable(false) }),
            items.map((item) => editId !== item.id
                ? react_1.default.createElement(Row_1.Row, { key: item.id + '', name: name, item: item, onDelete: handleDelete, onEdit: () => setEditId(item.id) })
                : react_1.default.createElement(EditableRow_1.EditableRow, { key: item.id + '', table: name, item: item, onSubmit: handleUpdate, onCancel: () => setEditId(0) }))));
}
exports.TableUI = TableUI;
