"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.moment = exports.now = exports.timestr = exports.datestr = exports.datetime = exports.logtime = exports.datef = exports.parseDate = void 0;
const _reDate = /^\d{8}$/;
function parseDate(date) {
    if (date instanceof Date)
        return date;
    else if (typeof date === 'number')
        return new Date(date);
    const str = date + '';
    if (_reDate.test(str)) {
        date = `${str.substr(0, 4)}-${str.substr(4, 2)}-${str.substr(6, 2)}`;
    }
    return new Date(date);
}
exports.parseDate = parseDate;
const formats = {
    YYYY: (d) => d.getFullYear() + '',
    MM: (d) => (d.getMonth() + 1 + '').padStart(2, '0'),
    dd: (d) => (d.getDate() + '').padStart(2, '0'),
    HH: (d) => (d.getHours() + '').padStart(2, '0'),
    mm: (d) => (d.getMinutes() + '').padStart(2, '0'),
    ss: (d) => (d.getSeconds() + '').padStart(2, '0'),
    ms: (d) => (d.getMilliseconds() + '').padStart(3, '0'),
};
/**
 * @param format full version 'YYYY-MM-dd HH:mm:ss.ms'
 */
function datef(date, format) {
    const d = parseDate(date);
    let str = format;
    Object.keys(formats).forEach(key => {
        const re = new RegExp(key, 'g');
        str = str.replace(re, formats[key](d));
    });
    return str;
}
exports.datef = datef;
function logtime(date = new Date()) {
    return datef(date, 'YYYY-MM-dd HH:mm:ss.ms');
}
exports.logtime = logtime;
function datetime(date = new Date()) {
    return datef(date, 'YYYY-MM-dd HH:mm:ss');
}
exports.datetime = datetime;
function datestr(date = new Date()) {
    return datef(date, 'YYYY-MM-dd');
}
exports.datestr = datestr;
function timestr(date = new Date()) {
    return datef(date, 'HH:mm:ss');
}
exports.timestr = timestr;
exports.now = Date.now;
function moment(date) {
    const _date = parseDate(date);
    const inv = exports.now() - _date.getTime();
    return inv > 86400 * 1000 ? datef(_date, 'MM.dd') : datef(_date, 'HH:mm');
}
exports.moment = moment;
